==> macopix-mascot-marimite-euc-ja-2.10.tar.gz: macopix-mascot-marimite-euc-ja-2.10/code_conv.sh <==
#!/bin/sh
ICONV="iconv"
#FROM_CODE="UTF8"
#TO_CODE="EUCJP"
TO_CODE="UTF8"
FROM_CODE="EUCJP"

TEMPFILE="./conv_temp"

$ICONV --from-code=$FROM_CODE --to-code=$TO_CODE marimite.menu          > $TEMPFILE
mv -f $TEMPFILE marimite.menu

$ICONV --from-code=$FROM_CODE --to-code=$TO_CODE marimite_youko.mcpx    > $TEMPFILE
mv -f $TEMPFILE marimite_youko.mcpx

$ICONV --from-code=$FROM_CODE --to-code=$TO_CODE marimite_sachiko.mcpx  > $TEMPFILE
mv -f $TEMPFILE marimite_sachiko.mcpx

$ICONV --from-code=$FROM_CODE --to-code=$TO_CODE marimite_yumi.mcpx     > $TEMPFILE
mv -f $TEMPFILE marimite_yumi.mcpx

$ICONV --from-code=$FROM_CODE --to-code=$TO_CODE marimite_sei.mcpx      > $TEMPFILE
mv -f $TEMPFILE marimite_sei.mcpx

$ICONV --from-code=$FROM_CODE --to-code=$TO_CODE marimite_shimako.mcpx  > $TEMPFILE
mv -f $TEMPFILE marimite_shimako.mcpx

$ICONV --from-code=$FROM_CODE --to-code=$TO_CODE marimite_noriko.mcpx  > $TEMPFILE
mv -f $TEMPFILE marimite_noriko.mcpx

$ICONV --from-code=$FROM_CODE --to-code=$TO_CODE marimite_eriko.mcpx    > $TEMPFILE
mv -f $TEMPFILE marimite_eriko.mcpx

$ICONV --from-code=$FROM_CODE --to-code=$TO_CODE marimite_rei.mcpx      > $TEMPFILE
mv -f $TEMPFILE marimite_rei.mcpx

$ICONV --from-code=$FROM_CODE --to-code=$TO_CODE marimite_yoshino.mcpx  > $TEMPFILE
mv -f $TEMPFILE marimite_yoshino.mcpx

$ICONV --from-code=$FROM_CODE --to-code=$TO_CODE marimite_shizuka.mcpx  > $TEMPFILE
mv -f $TEMPFILE marimite_shizuka.mcpx

$ICONV --from-code=$FROM_CODE --to-code=$TO_CODE marimite_tsutako.mcpx  > $TEMPFILE
mv -f $TEMPFILE marimite_tsutako.mcpx

$ICONV --from-code=$FROM_CODE --to-code=$TO_CODE marimite_minako.mcpx  > $TEMPFILE
mv -f $TEMPFILE marimite_minako.mcpx

$ICONV --from-code=$FROM_CODE --to-code=$TO_CODE marimite_mami.mcpx  > $TEMPFILE
mv -f $TEMPFILE marimite_mami.mcpx

$ICONV --from-code=$FROM_CODE --to-code=$TO_CODE marimite_touko.mcpx  > $TEMPFILE
mv -f $TEMPFILE marimite_touko.mcpx

$ICONV --from-code=$FROM_CODE --to-code=$TO_CODE marimite_srg.mcpx  > $TEMPFILE
mv -f $TEMPFILE marimite_srg.mcpx

==> macopix-mascot-marimite-euc-ja-2.20.tar.gz: macopix-mascot-marimite-euc-ja-2.20/code_conv.sh <==
#!/bin/sh
ICONV="iconv"
#FROM_CODE="UTF8"
#TO_CODE="EUCJP"
TO_CODE="UTF8"
FROM_CODE="EUCJP"

TEMPFILE="./conv_temp"

$ICONV --from-code=$FROM_CODE --to-code=$TO_CODE marimite.menu          > $TEMPFILE
mv -f $TEMPFILE marimite.menu

$ICONV --from-code=$FROM_CODE --to-code=$TO_CODE marimite_youko.mcpx    > $TEMPFILE
mv -f $TEMPFILE marimite_youko.mcpx

$ICONV --from-code=$FROM_CODE --to-code=$TO_CODE marimite_sachiko.mcpx  > $TEMPFILE
mv -f $TEMPFILE marimite_sachiko.mcpx

$ICONV --from-code=$FROM_CODE --to-code=$TO_CODE marimite_yumi.mcpx     > $TEMPFILE
mv -f $TEMPFILE marimite_yumi.mcpx

$ICONV --from-code=$FROM_CODE --to-code=$TO_CODE marimite_sei.mcpx      > $TEMPFILE
mv -f $TEMPFILE marimite_sei.mcpx

$ICONV --from-code=$FROM_CODE --to-code=$TO_CODE marimite_shimako.mcpx  > $TEMPFILE
mv -f $TEMPFILE marimite_shimako.mcpx

$ICONV --from-code=$FROM_CODE --to-code=$TO_CODE marimite_noriko.mcpx  > $TEMPFILE
mv -f $TEMPFILE marimite_noriko.mcpx

$ICONV --from-code=$FROM_CODE --to-code=$TO_CODE marimite_eriko.mcpx    > $TEMPFILE
mv -f $TEMPFILE marimite_eriko.mcpx

$ICONV --from-code=$FROM_CODE --to-code=$TO_CODE marimite_rei.mcpx      > $TEMPFILE
mv -f $TEMPFILE marimite_rei.mcpx

$ICONV --from-code=$FROM_CODE --to-code=$TO_CODE marimite_yoshino.mcpx  > $TEMPFILE
mv -f $TEMPFILE marimite_yoshino.mcpx

$ICONV --from-code=$FROM_CODE --to-code=$TO_CODE marimite_shizuka.mcpx  > $TEMPFILE
mv -f $TEMPFILE marimite_shizuka.mcpx

$ICONV --from-code=$FROM_CODE --to-code=$TO_CODE marimite_tsutako.mcpx  > $TEMPFILE
mv -f $TEMPFILE marimite_tsutako.mcpx

$ICONV --from-code=$FROM_CODE --to-code=$TO_CODE marimite_minako.mcpx  > $TEMPFILE
mv -f $TEMPFILE marimite_minako.mcpx

$ICONV --from-code=$FROM_CODE --to-code=$TO_CODE marimite_mami.mcpx  > $TEMPFILE
mv -f $TEMPFILE marimite_mami.mcpx

$ICONV --from-code=$FROM_CODE --to-code=$TO_CODE marimite_touko.mcpx  > $TEMPFILE
mv -f $TEMPFILE marimite_touko.mcpx

$ICONV --from-code=$FROM_CODE --to-code=$TO_CODE marimite_kanako.mcpx  > $TEMPFILE
mv -f $TEMPFILE marimite_kanako.mcpx

$ICONV --from-code=$FROM_CODE --to-code=$TO_CODE marimite_srg.mcpx  > $TEMPFILE
mv -f $TEMPFILE marimite_srg.mcpx
